import React, { useState, useEffect } from 'react';
import { Form, Button, Table, Pagination, Select, Input, Icon } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import apis from '../../../services/apis';
import request from '../../../utils/request'

/**
  @param {*} props
  @returns
 */
const { Option } = Select;

function record(props) {
    const [radioVal, updateRadioVal] = useState(7)
    const [formData, updateFormData] = useState({
        pageNum: 1,
        pageSize: 10,
        ...props.location.query,
    })

    // 获取初始化数据
    const [data, setData] = useState({})

    useEffect(() => {
        getList(formData);
    }, [])

    // 查询列表
    const getList = (params) => {
        request({ ...apis.stats.totalPersons, params: { ...params }, }).then((data) => {
            setData(data)
        })
    }

    //重置搜索
    function handleReset() {
        props.form.resetFields();
    }

    // 提交事件
    const handleSubmit = (e) => {
        e.preventDefault();
        props.form.validateFields((err, values) => {
            if (!err) {
                console.log('提交数据: ', values)

            }
        });
        // getList(formData);
    }
    // 更新页码
    const changePageNum = (pageNumber) => {
        props.form.validateFields((err, values) => {
            if (!err) {
                getList({ ...formData, pageNum: pageNumber });
            }
        });
    }


    // 表格数据
    const columns = [

        {
            title: '分享标题',
            dataIndex: 'intention',
            key: 'intention',
            align: 'center',
        },
        {
            title: '姓名',
            dataIndex: 'name',
            key: 'name',
            align: 'center',
        },
        {
            title: '电话',
            dataIndex: 'phone',
            key: 'phone',
            align: 'center',
        },
        {
            title: '性别',
            dataIndex: 'sex',
            key: 'sex',
            align: 'center',
            render: (_, record) => <span>{record.sex == 1 ? '男' : '女'}</span>,
        },
        {
            title: '访问时间',
            dataIndex: 'userName',
            key: 'userName',
            align: 'center',
            render: (_, record) => <><span>{record.reportDate && moment(record.reportDate).format('YYYY-MM-DD HH:mm:ss')}</span></>,
        },

    ];

    const { getFieldDecorator } = props.form
    return (

        <>
            <Button type="danger" style={{ margin: '0 0 18px 8px' }} onClick={() => router.go(-1)}>返回</Button>
            <Form layout="inline">
                <div style={{ display: 'flex', alignItems: 'center' }}>
                    <Form.Item>
                        {getFieldDecorator('eventType')(
                            <Select placeholder="分享类型" style={{ width: 150 }}>
                                <Option value="activity_share">报名活动</Option>
                                <Option value="help_share">助力活动</Option>
                                <Option value="group_share">拼团活动</Option>
                                <Option value="h5_share">H5活动</Option>
                                <Option value="live_share">直播活动</Option>
                                <Option value="house_share">房源列表</Option>
                                <Option value="building_share">项目</Option>
                                <Option value="news_share">资讯</Option>
                                <Option value="index_share">首页</Option>
                            </Select>
                        )}
                    </Form.Item>
                    <Form.Item>
                        {getFieldDecorator('activityName')(
                            <Input
                                prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                                placeholder="分享标题"
                            />,
                        )}
                    </Form.Item>
                    <Form.Item>
                        {getFieldDecorator('userName')(
                            <Input
                                prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                                placeholder="用户名"
                            />,
                        )}
                    </Form.Item>
                    <Form.Item style={{ position: 'absolute', right: '38px' }}>
                        <Button type="primary" onClick={handleSubmit}>搜索</Button>
                        <Button style={{ marginLeft: 8 }} onClick={handleReset}>重置</Button>
                    </Form.Item>
                </div>
            </Form>
            <Table rowKey={record => (record.userId + record.buildingId || '')}
                style={{ marginTop: '30px' }}
                dataSource={data.records}
                columns={columns}
                pagination={false}
            />
            < div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </>
    )
}
const WrappedHeader = Form.create({ name: 'record' })(record);

export default WrappedHeader
