import React, { useState, useEffect } from 'react';
import { Form, Button, DatePicker, Table, Pagination, Radio, Typography, Avatar } from 'antd';
import router from 'umi/router';
import moment from 'moment';
import BuildSelect from '../../../components/SelectButton/BuildSelect'
import apis from '../../../services/apis';
import request from '../../../utils/request'

/**
  @param {*} props
  @returns
 */
const { RangePicker } = DatePicker;
const { Text } = Typography;

function record(props) {
    const [formData, updateFormData] = useState({
        pageNum: 1,
        pageSize: 10,
        ...props.location.query,

    })

    // 获取初始化数据
    const [data, setData] = useState({})


    useEffect(() => {
        getList(formData);
    }, [])

    // 查询列表
    const getList = (params) => {
        request({ ...apis.stats.totalPersons, params: { ...params }, }).then((data) => {
            setData(data)
        })
    }

    // 更新页码
    const changePageNum = (pageNumber) => {
        props.form.validateFields((err, values) => {
            if (!err) {
                getList({ ...props.location.query, pageNum: pageNumber });
            }
        });
    }
    const toPersonDetail = (personId) => {
        router.push({
            pathname: '/customer/customerlist/publicCustomerDetail',
            query: {
                id: personId,
            },
        });
    }
    // 表格数据
    const columns = [
        {
            title: '姓名',
            dataIndex: 'name',
            key: 'name',
            align: 'center',
        },
        {
            title: '电话',
            dataIndex: 'phone',
            key: 'phone',
            align: 'center',
        },
        {
            title: '性别',
            dataIndex: 'sex',
            key: 'sex',
            align: 'center',
            render: (_, record) => <span>{record.sex == 1 ? '男' : '女'}</span>,
        },
        {
            title: '访问次数',
            dataIndex: 'visitNum',
            key: 'visitNum',
            align: 'center',
            render: (_, record) => <span style={{ color: 'blue', cursor: 'pointer' }} onClick={() => toPersonDetail(record.personId)} >{record.visitNum}</span>,
        },
        {
            title: '最后访问时间',
            dataIndex: 'reportDate',
            key: 'reportDate',
            align: 'center',
            render: (_, record) => <><span>{record.reportDate && moment(record.reportDate).format('YYYY-MM-DD HH:mm:ss')}</span></>,
        },

    ];

    return (

        <>
            <Button type="danger" style={{ marginLeft: '18px' }} onClick={() => router.go(-1)}>返回</Button>
            <Table rowKey={record => (record.phone + record.buildingId || '')}
                style={{ marginTop: '30px' }}
                dataSource={data.records}
                columns={columns}
                pagination={false}
            />
            < div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
                <Pagination showQuickJumper defaultCurrent={1} total={data.total} onChange={changePageNum} current={data.current} />
            </div>
        </>
    )
}
const WrappedHeader = Form.create({ name: 'record' })(record);

export default WrappedHeader
